@@ -136,6 +136,28 @@ class Client(Singleton):
             data = json.loads(data)
         
         return data
+
+    async def get_cache_async(self, key, toObj=True):
+        data = self.index_cache.get(key)
+        if data is None:
+            if self.redis is not None:
+                data = await self.redis.get(key)
+
+        if data is not None and toObj:
+            data = json.loads(data)
+        
+        return data
+
+    async def cache_async(self, key, val, ttl=7200):
+        if not isinstance(val, str):
+            _val = json.dumps(val)
+        else:
+            _val = val
+        try:
+            await self.redis.set(key, _val, expired=ttl)
+        except:
+            pass
+        self.index_cache.set(key, _val, expire=ttl)
             
     def put_to_cloud(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
@@ -154,14 +176,14 @@ class Client(Singleton):
 
     async def put_to_cloud_async(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
-        cache_data = self.get_cache(cache_key, toObj=False)
+        cache_data = await self.get_cache_async(cache_key, toObj=False)
         if cache_data is None:
             prefix, backend = self._random_pick_backend()
             
             ret, e = await backend.put_async(path, bucket, bucket_name, tmp)
             if ret:
                 url = '{}://{}'.format(prefix, e)
-                self.cache(cache_key, url)
+                await self.cache_async(cache_key, url)
                 return True, url
             return ret, e
         else:
@@ -381,7 +403,7 @@ class Client(Singleton):
                     if time.time() - t >= timeout:
                         break
                     
-                    resp = self.redis.get(task_id)
+                    resp = await self.redis.get(task_id)
                     
                     if resp is not None and len(resp) > 0:
                         resp = json.loads(resp)
