@@ -82,23 +82,17 @@ class MQManager(Singleton):
             print('publishing')
 
             if mq is None:
-                if self.inited:
-                    mq = self.mq
-                else:
-                    self._init()
-                    mq = self.mq
+                mq = await self.get_mq_conn()
 
             ret = await mq.pub(topic, message)
             max_t = 5
             t = 0
             while not ret and t < max_t: 
                 try:
-                    ret = await mq.pub(topic, message)
+                    ret = await mq.pub(topic, message).isok
                 except:
                     ret = False
                 t += 1
-            if ret:
-                print('published')    
             return ret
         except Exception as e:
             print(traceback.print_exc())
